"""
SAMPLE GRADER for task SWAPS

USAGE:
place together with your solution in the same directory, then:
python3 sample_grader.py <solutionFile>
e.g.:
python3 sample_grader.py swaps.py

INPUT/OUTPUT:
The sample grader expects on standard input the numbers N and V as well as a
list of N integers, the rooms ordered by decreasing aesthetic value at the
beginning of solve. Then, the grader writes to standard output a protocol of
all grader functions called by your program. Whenever schedule(i, j) is called,
the grader expects on standard input the number 1 if the art collections of
rooms i and j should be swapped at that point in time, or 0 otherwise.
At the end, the grader prints your verdict.
"""
import sys
from typing import List


def result(msg):
    print(msg, file=sys.stderr)
    sys.exit(0)


queryIndices = set()
A = []
queryResult = []
visits = 0


def schedule(i: int, j: int):
    print(f"schedule({i}, {j})", flush=True)

    if i < 1 or i > N or j < 1 or j > N or i == j:
        result("Invalid schedule")
    if i in queryIndices or j in queryIndices:
        result("Invalid schedule")
    queryIndices.add(i)
    queryIndices.add(j)

    s = int(input())
    if s != 0 and s != 1:
        result("Invalid input")
    if s == 1:
        A[i], A[j] = A[j], A[i]
    queryResult.append(1 if A[i] < A[j] else 0)


def visit() -> List[int]:
    global visits
    print(f"visit(): {{{', '.join(map(str, queryResult))}}}", flush=True)
    visits += 1
    if visits > V:
        result("Out of visits")

    res = queryResult.copy()
    queryIndices.clear()
    queryResult.clear()
    return res


def answer(r: List[int]):
    print(f"answer({{{', '.join(map(str, r))}}})")

    if len(r) != N:
        result("Invalid answer")

    if any(x < 1 or x > N for x in r):
        result("Invalid answer")
    if any(A[r[i]] != i + 1 for i in range(N)):
        result("Wrong answer")

    result(f"Correct: {visits} visit(s) used")


if __name__ == "__main__":
    # import task as solution
    filename = sys.argv[1] if len(sys.argv) > 1 else "swaps.py"
    if filename.endswith(".py"):
        filename = filename[:-3]
    try:
        solution = __import__(filename)
    except Exception as e:
        print("USAGE: python3 sample_grader.py <solutionFile>\nError:",
              e, file=sys.stderr)
        sys.exit(1)
    solution.schedule = schedule
    solution.visit = visit
    solution.answer = answer

    N, V = list(map(int, input().split()))
    if N < 1 or V < 0:
        result("Invalid input")
    A = [0] * (N + 1)

    order = list(map(int, input().split()))
    if len(order) != N:
        result("Invalid input")
    for i in range(N):
        x = order[i]
        if x < 1 or x > N or A[x] != 0:
            result("Invalid input")
        A[x] = i+1

    solution.solve(N, V)

    result("No answer")
